function [ret,x0,str,ts,xts]=tumble_4(t,x,u,flag);
%TUMBLE_4	is the M-file description of the SIMULINK system named TUMBLE_4.
%	The block-diagram can be displayed by typing: TUMBLE_4.
%
%	SYS=TUMBLE_4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TUMBLE_4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TUMBLE_4 with a FLAG of zero:
%	[SIZES]=TUMBLE_4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[-8,129,1256,1046])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '20000')
set_param(sys,'Min step size', '0.5')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,580,380,646])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[525,525,530,530])

add_block('built-in/Note',[sys,'/',['QUATERNIONS : ETUDE DU TANGAGE ROULIS ET LACET',13,'']])
set_param([sys,'/',['QUATERNIONS : ETUDE DU TANGAGE ROULIS ET LACET',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[720,5,725,10])

add_block('built-in/Note',[sys,'/','Rduction du tumbling ( technique de Steyn )'])
set_param([sys,'/','Rduction du tumbling ( technique de Steyn )'],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[708,45,713,50])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[705,460,710,465])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[295,465,300,470])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[480,440,485,445])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[535,195,540,200])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,80,1268,1004])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[330,259,455,311])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','2500',...
		'position',[320,340,385,370])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[210,255,260,375])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[280,345,285,350])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[285,250,290,255])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[70,180,90,200])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[100,215,105,220])

add_block('built-in/Note',[sys,'/',['UnNamed1/tau',13,'']])
set_param([sys,'/',['UnNamed1/tau',13,'']],...
		'position',[80,120,85,125])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,50,1271,885])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[235,162,365,218])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[795,180,815,200])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[725,177,750,203])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'inputs','+++',...
		'position',[650,49,690,331])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[530,72,630,118])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'Gain','K_perturbation',...
		'position',[575,177,600,203])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Inverse matrice',13,'satellite1']])
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[415,167,515,213])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'Gain','K_commande',...
		'position',[470,83,510,107])


%     Subsystem  'UnNamed1/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem1'],'Location',[4,237,1241,959])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']])
set_param([sys,'/',['UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[620,10,625,15])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,47,600,52])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Outport1'])
set_param([sys,'/','UnNamed1/Subsystem1/Outport1'],...
		'hide name',0,...
		'position',[1065,430,1085,450])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace6'],...
		'hide name',0,...
		'mat-name','Mz',...
		'buffer','points_trace',...
		'position',[620,464,655,486])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace3'],...
		'hide name',0,...
		'mat-name','My',...
		'buffer','points_trace',...
		'position',[620,384,655,406])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace2'],...
		'hide name',0,...
		'mat-name','Mx',...
		'buffer','points_trace',...
		'position',[615,309,650,331])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[655,256,695,494])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Couple',13,' magntique']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple',13,' magntique']],...
		'position',[810,370,815,375])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux4'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[720,312,755,563])


%     Subsystem  'UnNamed1/Subsystem1/Calcul de My'.

new_system([sys,'/','UnNamed1/Subsystem1/Calcul de My'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My'],'Location',[6,256,1237,988])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/Puissance',13,'et',13,'couple']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/Puissance',13,'et',13,'couple']],...
		'position',[655,425,660,430])

add_block('built-in/Saturation',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Saturation'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Saturation'],...
		'Lower Limit','-mom_mgn_max',...
		'Upper Limit','mom_mgn_max',...
		'position',[665,339,690,381])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Calcul de My/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/To Workspace2'],...
		'hide name',0,...
		'mat-name','my',...
		'buffer','points_trace',...
		'position',[1065,410,1145,430])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Calcul de My/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/To Workspace3'],...
		'hide name',0,...
		'mat-name','beta_steyn',...
		'buffer','points_trace',...
		'position',[460,455,540,475])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/Couple',13,' magntique']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/Couple',13,' magntique']],...
		'position',[870,478,875,483])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Constant'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Constant'],...
		'hide name',0,...
		'Value','0',...
		'position',[710,380,730,400])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[710,430,730,450])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/Couple magntique',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/Couple magntique',13,'']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[840,436,930,474])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux4'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[795,377,825,528])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[745,375,775,455])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/My',13,'vecteur']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/My',13,'vecteur']],...
		'position',[760,450,765,455])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux2'],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[950,411,985,589])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/My prvu pour que la puissance du couple soit ngative'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/My prvu pour que la puissance du couple soit ngative'],...
		'position',[570,50,575,55])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/CALCUL DE My AVEC SATURATION '])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/CALCUL DE My AVEC SATURATION '],...
		'Font Name','Arial Narrow',...
		'Font Size',18,...
		'position',[570,15,575,20])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Vecteur champ'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Vecteur champ'],...
		'position',[465,490,470,495])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/pqrQ  '])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/pqrQ  '],...
		'position',[470,515,475,520])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Calcul de My/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/out_1'],...
		'position',[1115,350,1135,370])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/Sortie du moment',13,'magntique My']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/Sortie du moment',13,'magntique My']],...
		'position',[1105,305,1110,310])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/Couple magntique',13,'1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/Couple magntique',13,'1']],...
		'hide name',0,...
		'MATLAB Fcn','puis_0(u)',...
		'Output Width','1',...
		'position',[1000,483,1060,517])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Calcul de My/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/To Workspace1'],...
		'hide name',0,...
		'mat-name','puissance_steyn',...
		'buffer','points_trace',...
		'position',[1075,489,1185,511])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Gain'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Gain'],...
		'hide name',0,...
		'Gain','K_beta',...
		'position',[605,346,650,374])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Mux1'],...
		'hide name',0,...
		'inputs','[7 3 1]',...
		'position',[355,270,385,360])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Derivative'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Derivative'],...
		'hide name',0,...
		'position',[275,388,325,422])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/Calcul de My/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','beta_tg(u)',...
		'Output Width','1',...
		'Mask Display','beta_tg',...
		'position',[190,388,250,422])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/B  '])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/B  '],...
		'position',[120,435,125,440])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Calcul de My/in_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/in_2'],...
		'position',[45,275,65,295])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Calcul de My/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/in_1'],...
		'Port','2',...
		'position',[105,395,125,415])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Calcul de My/beta',13,'prime']])
set_param([sys,'/',['UnNamed1/Subsystem1/Calcul de My/beta',13,'prime']],...
		'position',[380,365,385,370])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Gain1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Gain1'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[295,446,350,484])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/pqrQ'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/pqrQ'],...
		'position',[205,250,210,255])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/beta et beta_prime'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/beta et beta_prime'],...
		'hide name',0,...
		'position',[290,355,295,360])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/B'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/B'],...
		'hide name',0,...
		'position',[350,470,355,475])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/signe'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/signe'],...
		'position',[440,270,445,275])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/Calcul de My/MATLAB Fcn1'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','-sign(u(11)*(u(1)*u(10)-u(3)*u(8)))',...
		'Output Width','1',...
		'position',[410,298,470,332])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Product'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Product'],...
		'inputs','3',...
		'position',[560,297,585,423])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Clock'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Clock'],...
		'position',[235,192,270,228])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/Calcul de My/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase1)<0',...
		'Output Width','1',...
		'position',[350,193,410,227])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Calcul de My/Arrt de la premire phase'])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My/Arrt de la premire phase'],...
		'position',[325,165,330,170])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[695,360;1110,360])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[655,360;660,360])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[255,405;255,465;290,465])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[355,465;455,465])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[255,405;270,405])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[330,405;330,345;350,345])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[390,315;405,315])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[1065,500;1070,500])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[590,360;600,360])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[830,455;835,455])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[1035,360;1035,420;1060,420])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[935,455;945,455])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[990,500;995,500])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[735,390;740,390])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[780,415;790,415])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[695,360;695,415;740,415])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[735,440;740,440])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[70,285;350,285])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[70,285;70,545;945,545])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[275,210;345,210])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[330,405;555,400])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[475,315;490,315;490,360;555,360])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[415,210;515,210;515,320;555,320])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[130,405;145,405;145,490;790,490])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[145,405;175,405;185,405])
add_line([sys,'/','UnNamed1/Subsystem1/Calcul de My'],[146,405;145,315;350,315])
set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My'],...
		'Mask Display','Calcul de My\ncommande de Steyn\navec l''angle beta driv')


%     Finished composite block 'UnNamed1/Subsystem1/Calcul de My'.

set_param([sys,'/','UnNamed1/Subsystem1/Calcul de My'],...
		'hide name',0,...
		'position',[440,337,595,413])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[775,421,865,459])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux3'],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[350,409,385,496])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/pqrQ '])
set_param([sys,'/','UnNamed1/Subsystem1/pqrQ '],...
		'position',[205,260,210,265])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie B',13,'axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie B',13,'axes satellite']],...
		'hide name',0,...
		'position',[200,280,205,285])


%     Subsystem  ['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],'Location',[59,535,1014,1004])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[250,95,425,145])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[885,150,905,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Axes satellite']],...
		'position',[875,110,880,115])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[880,85,885,90])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[625,160;880,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],...
		'position',[110,332,310,408])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/in_1'],...
		'hide name',0,...
		'position',[25,360,45,380])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'hide name',0,...
		'position',[50,450,55,455])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/pqrQ'])
set_param([sys,'/','UnNamed1/Subsystem1/pqrQ'],...
		'position',[195,545,200,550])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace5'],...
		'hide name',0,...
		'mat-name','angle_Y_y',...
		'buffer','points_trace',...
		'position',[490,565,570,585])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/MATLAB Fcn1'])
set_param([sys,'/','UnNamed1/Subsystem1/MATLAB Fcn1'],...
		'MATLAB Fcn','180/pi*acos((2*(u(4)^2+u(6)^2)-1))',...
		'Output Width','1',...
		'position',[375,558,435,592])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_steyn',...
		'buffer','points_trace',...
		'position',[935,400,1015,420])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Couple de',13,'Steyn gnral']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple de',13,'Steyn gnral']],...
		'position',[970,355,975,360])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1'],'Location',[720,262481,1180,262716])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem1/Subsystem1/Clock'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1/Clock'],...
		'position',[130,87,165,123])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/Subsystem1/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase2)>0',...
		'Output Width','1',...
		'position',[215,88,275,122])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem1/Arrt de la premire phase'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1/Arrt de la premire phase'],...
		'position',[195,55,200,60])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem1/Subsystem1/Product'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1/Product'],...
		'position',[315,74,340,201])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem1/Couple magntique',13,'4']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem1/Couple magntique',13,'4']],...
		'hide name',0,...
		'MATLAB Fcn','Mx_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mx\navec saturation',...
		'position',[120,146,275,194])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem1/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1/out_1'],...
		'position',[370,130,390,150])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1/in_1'],...
		'position',[70,160,90,180])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem1'],[280,105;310,105])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem1'],[280,170;310,170])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem1'],[170,105;210,105])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem1'],[345,140;365,140])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem1'],[95,170;115,170])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1'],...
		'Mask Display','CALCUL DE Mx\nSATURATION\nDEMARRAGE')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem1'],...
		'position',[435,270,595,320])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem2'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2'],'Location',[775,262486,1110,262736])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem2/Couple magntique',13,'3']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem2/Couple magntique',13,'3']],...
		'hide name',0,...
		'MATLAB Fcn','Mz_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mz\navec saturation',...
		'position',[70,141,225,189])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem1/Subsystem2/Clock'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2/Clock'],...
		'position',[75,82,110,118])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem1/Subsystem2/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase2)>0',...
		'Output Width','1',...
		'position',[160,83,220,117])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem2/Arrt de la premire phase'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2/Arrt de la premire phase'],...
		'position',[140,50,145,55])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem1/Subsystem2/Product'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2/Product'],...
		'position',[260,69,285,196])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem2/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2/out_1'],...
		'position',[315,125,335,145])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem2/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2/in_1'],...
		'position',[15,155,35,175])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem2'],[225,100;255,100])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem2'],[230,165;255,165])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem2'],[115,100;155,100])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem2'],[290,135;310,135])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem2'],[40,165;65,165])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2'],...
		'Mask Display','CALCUL DE Mz\nSATURATION\nDEMARRAGE')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem2'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem2'],...
		'position',[440,427,590,483])
add_line([sys,'/','UnNamed1/Subsystem1'],[50,370;105,370])
add_line([sys,'/','UnNamed1/Subsystem1'],[440,575;485,575])
add_line([sys,'/','UnNamed1/Subsystem1'],[65,370;65,290;330,290;330,355;435,355])
add_line([sys,'/','UnNamed1/Subsystem1'],[390,455;400,455;400,295;430,295])
add_line([sys,'/','UnNamed1/Subsystem1'],[600,295;650,295])
add_line([sys,'/','UnNamed1/Subsystem1'],[600,375;650,375])
add_line([sys,'/','UnNamed1/Subsystem1'],[595,455;650,455])
add_line([sys,'/','UnNamed1/Subsystem1'],[390,455;435,455])
add_line([sys,'/','UnNamed1/Subsystem1'],[65,370;65,475;345,475])
add_line([sys,'/','UnNamed1/Subsystem1'],[315,370;325,370;325,430;345,430])
add_line([sys,'/','UnNamed1/Subsystem1'],[760,440;770,440])
add_line([sys,'/','UnNamed1/Subsystem1'],[700,375;715,375])
add_line([sys,'/','UnNamed1/Subsystem1'],[325,430;325,500;715,500])
add_line([sys,'/','UnNamed1/Subsystem1'],[325,395;435,395])
add_line([sys,'/','UnNamed1/Subsystem1'],[600,295;610,320])
add_line([sys,'/','UnNamed1/Subsystem1'],[600,375;600,395;615,395])
add_line([sys,'/','UnNamed1/Subsystem1'],[595,455;595,475;615,475])
add_line([sys,'/','UnNamed1/Subsystem1'],[870,440;1060,440])
add_line([sys,'/','UnNamed1/Subsystem1'],[885,440;885,410;930,410])
add_line([sys,'/','UnNamed1/Subsystem1'],[65,475;65,575;370,575])
set_param([sys,'/','UnNamed1/Subsystem1'],...
		'Mask Display','REGULATION TUMBLING \nDE\nSTEYN')


%     Finished composite block 'UnNamed1/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem1'],...
		'hide name',0,...
		'position',[225,54,445,136])
add_line([sys,'/','UnNamed1'],[265,285;325,285])
add_line([sys,'/','UnNamed1'],[265,345;305,345;315,355])
add_line([sys,'/','UnNamed1'],[460,285;645,285])
add_line([sys,'/','UnNamed1'],[695,190;720,190])
add_line([sys,'/','UnNamed1'],[755,190;790,190])
add_line([sys,'/','UnNamed1'],[95,190;230,190])
add_line([sys,'/','UnNamed1'],[185,190;185,315;205,315])
add_line([sys,'/','UnNamed1'],[605,190;645,190])
add_line([sys,'/','UnNamed1'],[185,190;185,95;220,95])
add_line([sys,'/','UnNamed1'],[450,95;465,95])
add_line([sys,'/','UnNamed1'],[635,95;645,95])
add_line([sys,'/','UnNamed1'],[515,95;525,95])
add_line([sys,'/','UnNamed1'],[370,190;410,190])
add_line([sys,'/','UnNamed1'],[520,190;570,190])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,188,465,272])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[525,375,530,380])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[235,323,450,427])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[610,159,670,446])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[735,279,835,331])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[630,210,635,215])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[625,350,630,355])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,77,1267,1004])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,624,1000,656])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusr2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Note',[sys,'/','Subsystem/Vrification  rotation transversale'])
set_param([sys,'/','Subsystem/Vrification  rotation transversale'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[805,295,810,300])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[790,165,860,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[785,200,855,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[795,235,865,255])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs1']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs1']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[720,162,745,188])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs2']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs2']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[720,197,745,223])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs3']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs3']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[720,232,745,258])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope'])
set_param([sys,'/','Subsystem/Scope'],...
		'Vgain','0.200000',...
		'Hgain','5000.000000',...
		'Vmax','0.400000',...
		'Hmax','10000.000000',...
		'Window',[314,357,1072,756],...
		'position',[620,110,650,140])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[635,15,640,20])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']],...
		'position',[960,165,965,170])

add_block('built-in/Note',[sys,'/','Subsystem/Angles en degrs'])
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'position',[1095,465,1100,470])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;795,285])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;910,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;715,175])
add_line([sys,'/','Subsystem'],[750,175;785,175])
add_line([sys,'/','Subsystem'],[660,210;715,210])
add_line([sys,'/','Subsystem'],[750,210;780,210])
add_line([sys,'/','Subsystem'],[750,245;790,245])
add_line([sys,'/','Subsystem'],[660,245;715,245])
add_line([sys,'/','Subsystem'],[550,210;550,125;615,125])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[955,156,1150,229])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[900,210,905,215])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[900,145,905,150])

add_block('built-in/Note',[sys,'/',['****************************************************************',13,'']])
set_param([sys,'/',['****************************************************************',13,'']],...
		'Font Size',12,...
		'position',[1115,395,1120,400])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[559,482,1161,775])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[735,148,820,202])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[165,93,200,127])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,''''y'''',temps,q,''''c'''',temps,r,''''m'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[175,660,380,721])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMx',...
		'Mask Dialogue','eval(''plot(temps,Mx);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[400,585,670,646])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMy',...
		'Mask Dialogue','eval(''plot(temps,my);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[400,655,670,716])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMz',...
		'Mask Dialogue','eval(''plot(temps,Mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[400,720,670,781])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir la courbe\n\npuissance (W)',...
		'Mask Dialogue','eval(''plot(temps,puissance_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,655,865,721])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[695,580,865,646])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir la courbe\nangle beta(B,y)\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,beta_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[175,730,380,781])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Voir la courbe\nangle entre Y et y\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,angle_Y_y);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[770,810,945,876])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Vrification\n\nq constante',...
		'Mask Dialogue','eval(''plot(temps,q);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[575,810,750,876])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Vrification\n\nenergie constante',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[375,810,550,876])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Vrification\np2plusr2 constante\nrotation transverse',...
		'Mask Dialogue','eval(''plot(temps,p2plusr2);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[175,810,350,881])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,44,1012,680])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=cyan\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[905,655,1135,741])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,735,865,801])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''steyndat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[890,310,1105,381])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance steyndat.m']])
set_param([sys,'/',['L''initialisation',13,' lance steyndat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1190,315,1195,320])
add_line(sys,[840,305;860,305;860,460;150,460;150,375;230,375])
add_line(sys,[675,305;730,305])
add_line(sys,[470,230;605,230])
add_line(sys,[455,375;605,375])
add_line(sys,[860,305;860,175;950,175])
add_line(sys,[710,305;710,210;950,210])
add_line(sys,[150,375;150,230;235,230])
add_line(sys,[860,175;825,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
